about summary refs log tree commit diff stats
path: root/src/command/cmd_defs.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/command/cmd_defs.c')
-rw-r--r--src/command/cmd_defs.c58
1 files changed, 29 insertions, 29 deletions
diff --git a/src/command/cmd_defs.c b/src/command/cmd_defs.c
index e8a97398..9bc8b6f2 100644
--- a/src/command/cmd_defs.c
+++ b/src/command/cmd_defs.c
@@ -5,20 +5,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -48,7 +48,7 @@
 
 #include <glib.h>
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "log.h"
 #include "common.h"
 #include "command/cmd_defs.h"
@@ -113,7 +113,7 @@ static const struct cmd_t command_defs[] = {
       CMD_SYN(
               "/help [<area>|<command>|search_all|search_any] [<search_terms>]")
       CMD_DESC(
-              "Help on using Profanity. Passing no arguments list help areas. "
+              "Help on using Profani-tty. Passing no arguments list help areas. "
               "For command help, optional arguments are shown using square brackets, "
               "arguments representing variables rather than a literal name are surrounded by angle brackets. "
               "Arguments that may be one of a number of values are separated by a pipe "
@@ -417,7 +417,7 @@ static const struct cmd_t command_defs[] = {
       CMD_EXAMPLES(
               "/blocked add hel@helheim.edda",
               "/blocked report-spam hel@helheim.edda Very annoying guy",
-              "/blocked add profanity@rooms.dismail.de/spammy-user")
+              "/blocked add profani-tty@a3.pm/spammy-user")
     },
 
     { CMD_PREAMBLE("/info",
@@ -554,8 +554,8 @@ static const struct cmd_t command_defs[] = {
               { "password <password>", "Password if the room requires one." })
       CMD_EXAMPLES(
               "/join",
-              "/join profanity@rooms.dismail.de",
-              "/join profanity@rooms.dismail.de nick mynick",
+              "/join profani-tty@a3.pm",
+              "/join profani-tty@a3.pm nick mynick",
               "/join private@conference.jabber.org nick mynick password mypassword",
               "/join mychannel")
     },
@@ -580,7 +580,7 @@ static const struct cmd_t command_defs[] = {
               { "decline <room>", "Decline a chat room invitation." })
       CMD_EXAMPLES(
               "/invite send gustavo@pollos.tx",
-              "/invite decline profanity@rooms.dismail.de",
+              "/invite decline profani-tty@a3.pm",
               "/invite list")
     },
 
@@ -791,7 +791,7 @@ static const struct cmd_t command_defs[] = {
       CMD_DESC(
               "Manage bookmarks and join bookmarked rooms. "
               "If you are in a chat room and no arguments are supplied to `/bookmark add`, autojoin is set to \"on\". "
-              "There is also an autojoin ignore list in case you want to autojoin in many clients but not on Profanity. ")
+              "There is also an autojoin ignore list in case you want to autojoin in many clients but not on Profani-tty. ")
       CMD_ARGS(
               { "list [<jid>]", "List all bookmarks. Or the details of one." },
               { "add [<room>]", "Add a bookmark, passing no room will bookmark the current room, setting autojoin to \"on\"." },
@@ -1063,7 +1063,7 @@ static const struct cmd_t command_defs[] = {
         CMD_SYN(
                "/quit")
        CMD_DESC(
-               "Logout of any current session, and quit Profanity.")
+               "Logout of any current session, and quit Profani-tty.")
     },
 
     { CMD_PREAMBLE("/privileges",
@@ -1559,9 +1559,9 @@ static const struct cmd_t command_defs[] = {
       CMD_ARGS(
               { "get [<nick|contact>]", "Get your vCard, if a nickname/contact is provided, get that user's vCard" },
               { "photo open <nick|contact> [<index>]", "Download a user's photo from their vCard to a file, and open it. If index is not specified, download the first photo (usually avatar) from their vCard" },
-              { "photo save <nick|contact>", "Download a user's photo from their vCard to a file. If index is not specified, download the first photo (usually avatar) from their vCard. If output is not specified, download the photo to profanity's photos directory." },
+              { "photo save <nick|contact>", "Download a user's photo from their vCard to a file. If index is not specified, download the first photo (usually avatar) from their vCard. If output is not specified, download the photo to profani-tty's photos directory." },
               { "photo open-self [<index>]", "Download a photo from your vCard to a file, and open it. If index is not specified, download the first photo (usually avatar) from your vCard" },
-              { "photo save-self", "Download a photo from your vCard to a file. If index is not specified, download the first photo (usually avatar) from your vCard. If output is not specified, download the photo to profanity's photos directory. Same arguments as `photo open`" },
+              { "photo save-self", "Download a photo from your vCard to a file. If index is not specified, download the first photo (usually avatar) from your vCard. If output is not specified, download the photo to profani-tty's photos directory. Same arguments as `photo open`" },
               { "set fullname <fullname>", "Set your vCard's fullname to the specified value" },
               { "set name family <family>", "Set your vCard's family name to the specified value" },
               { "set name given <given>", "Set your vCard's given name to the specified value" },
@@ -1616,7 +1616,7 @@ static const struct cmd_t command_defs[] = {
       CMD_SYN(
               "/vercheck on|off")
       CMD_DESC(
-              "Check for new versions when Profanity starts, and when the /about command is run.")
+              "Check for new versions when Profani-tty starts, and when the /about command is run.")
       CMD_ARGS(
               { "on|off", "Enable or disable the version check." })
     },
@@ -1630,10 +1630,10 @@ static const struct cmd_t command_defs[] = {
               "/wintitle show on|off",
               "/wintitle goodbye on|off")
       CMD_DESC(
-              "Allow Profanity to modify the window title bar.")
+              "Allow Profani-tty to modify the window title bar.")
       CMD_ARGS(
               { "show on|off", "Show current logged in user, and unread messages as the window title." },
-              { "goodbye on|off", "Show a message in the title when exiting profanity." })
+              { "goodbye on|off", "Show a message in the title when exiting profani-tty." })
     },
 
     { CMD_PREAMBLE("/alias",
@@ -1752,7 +1752,7 @@ static const struct cmd_t command_defs[] = {
              "OpenPGP (OX) commands to manage keys, and perform OpenPGP encryption during chat sessions. "
              "Your OpenPGP key needs a user-id with your JID URI (xmpp:local@domain.tld). "
              "A key can be generated with \"gpg --quick-gen-key xmpp:local@domain.tld future-default default 3y\". "
-             "See man profanity-ox-setup for details on how to set up OX the first time.")
+             "See man profani-tty-ox-setup for details on how to set up OX the first time.")
       CMD_ARGS(
               { "keys", "List all keys known to the system." },
               { "contacts", "Show contacts with assigned public keys." },
@@ -1895,12 +1895,12 @@ static const struct cmd_t command_defs[] = {
               "/log shared on|off",
               "/log level INFO|DEBUG|WARN|ERROR")
       CMD_DESC(
-              "Manage profanity log settings.")
+              "Manage profani-tty log settings.")
       CMD_ARGS(
               { "where", "Show the current log file location." },
-              { "rotate on|off", "Rotate log, default on. Does not take effect if you specified a filename yourself when starting Profanity." },
+              { "rotate on|off", "Rotate log, default on. Does not take effect if you specified a filename yourself when starting Profani-tty." },
               { "maxsize <bytes>", "With rotate enabled, specifies the max log size, defaults to 10485760 (10MB)." },
-              { "shared on|off", "Share logs between all instances, default: on. When off, the process id will be included in the log filename. Does not take effect if you specified a filename yourself when starting Profanity." },
+              { "shared on|off", "Share logs between all instances, default: on. When off, the process id will be included in the log filename. Does not take effect if you specified a filename yourself when starting Profani-tty." },
               {"level INFO|DEBUG|WARN|ERROR", "Set the log level. Default is INFO. Only works with default log file, not with user provided log file during startup via -f." })
     },
 
@@ -2101,7 +2101,7 @@ static const struct cmd_t command_defs[] = {
               { "set <account> status <presence>", "The presence status to use on login." },
               { "set <account> status last", "Use your last status before logging out, when logging in." },
               { "set <account> <presence> <priority>", "Set the priority (-128..127) to use for the specified presence." },
-              { "set <account> resource <resource>", "The resource to be used for this account, defaults to 'profanity'." },
+              { "set <account> resource <resource>", "The resource to be used for this account, defaults to 'profani-tty'." },
               { "set <account> password <password>", "Password for the account, note this is currently stored in plaintext if set." },
               { "set <account> eval_password <command>", "Shell command evaluated to retrieve password for the account. Can be used to retrieve password from keyring." },
               { "set <account> muc <service>", "The default MUC chat service to use, defaults to the servers disco info response." },
@@ -2140,7 +2140,7 @@ static const struct cmd_t command_defs[] = {
               "/account set me nick dennis",
               "/account set me status dnd",
               "/account set me dnd -1",
-              "/account set me clientid \"Profanity 0.42 (Dev)\"",
+              "/account set me clientid \"Profani-tty 0.42 (Dev)\"",
               "/account rename me chattyme",
               "/account clear me pgpkeyid")
     },
@@ -2250,7 +2250,7 @@ static const struct cmd_t command_defs[] = {
               "/script show <script>")
       CMD_DESC(
               "Run command scripts. "
-              "Scripts are stored in $XDG_DATA_HOME/profanity/scripts/ which is usually $HOME/.local/share/profanity/scripts/.")
+              "Scripts are stored in $XDG_DATA_HOME/profani-tty/scripts/ which is usually $HOME/.local/share/profani-tty/scripts/.")
       CMD_ARGS(
               { "script run <script>", "Execute a script." },
               { "script list", "List all scripts TODO." },
@@ -2587,8 +2587,8 @@ static const struct cmd_t command_defs[] = {
               { "open", "Open URL with predefined executable." },
               { "save", "Save URL to optional path, default path is current directory." })
       CMD_EXAMPLES(
-              "/url open https://profanity-im.github.io",
-              "/url save https://profanity-im.github.io/guide/latest/userguide.html /home/user/Download/")
+              "/url open https://profani-tty.github.io",
+              "/url save https://profani-tty.github.io/guide/latest/userguide.html /home/user/Download/")
     },
 
     { CMD_PREAMBLE("/mam",
@@ -2695,7 +2695,7 @@ static const struct cmd_t command_defs[] = {
               { "set <mood> [text]", "Set user mood to <mood> with an optional [text]. Use /mood set <tab> to toggle through predefined moods." },
               { "clear", "Clear your user mood." })
       CMD_EXAMPLES(
-              "/mood set happy \"So happy to use Profanity!\"",
+              "/mood set happy \"So happy to use Profani-tty!\"",
               "/mood set amazed",
               "/mood clear")
     },
@@ -3022,7 +3022,7 @@ command_mangen(void)
 
     GDateTime* now = g_date_time_new_now_local();
     gchar* date = g_date_time_format(now, "%F");
-    gchar* header = g_strdup_printf(".TH man 1 \"%s\" \"" PACKAGE_VERSION "\" \"Profanity XMPP client\"\n", date);
+    gchar* header = g_strdup_printf(".TH man 1 \"%s\" \"" PACKAGE_VERSION "\" \"Profani-tty XMPP client\"\n", date);
     if (!header) {
         log_error("command_mangen(): could not allocate memory");
         return;
@@ -3034,7 +3034,7 @@ command_mangen(void)
     while (curr) {
         Command* pcmd = curr->data;
 
-        gchar* filename = g_strdup_printf("docs/profanity-%s.1", &pcmd->cmd[1]);
+        gchar* filename = g_strdup_printf("docs/profani-tty-%s.1", &pcmd->cmd[1]);
         if (!filename) {
             log_error("command_mangen(): could not allocate memory");
             return;
@@ -5,20 +5,20 @@
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -5,20 +5,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -5,20 +5,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the